# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EvaluationStats(Model):
    """Represents measure evaluation stats.

    :param last_successful: Last successful evaluation
    :type last_successful: datetime
    :param consecutive_failure_count: Represents Number of consecutive
     failures
    :type consecutive_failure_count: int
    """

    _attribute_map = {
        'last_successful': {'key': 'lastSuccessful', 'type': 'iso-8601'},
        'consecutive_failure_count': {'key': 'consecutiveFailureCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EvaluationStats, self).__init__(**kwargs)
        self.last_successful = kwargs.get('last_successful', None)
        self.consecutive_failure_count = kwargs.get('consecutive_failure_count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataRefreshSchedule(Model):
    """Represents a refresh schedule for the state machine.

    :param is_active: Gets a value indicating whether the schedule is active.
    :type is_active: bool
    :param timezone_id: Gets the ID of the timezone
    :type timezone_id: str
    :param cron_schedules: Gets the schedule in CRON format
    :type cron_schedules: list[str]
    :param schedule_id: Gets the ID of the schedule
    :type schedule_id: str
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'timezone_id': {'key': 'timezoneId', 'type': 'str'},
        'cron_schedules': {'key': 'cronSchedules', 'type': '[str]'},
        'schedule_id': {'key': 'scheduleId', 'type': 'str'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, is_active: bool=None, timezone_id: str=None, cron_schedules=None, schedule_id: str=None, instance_id: str=None, **kwargs) -> None:
        super(DataRefreshSchedule, self).__init__(**kwargs)
        self.is_active = is_active
        self.timezone_id = timezone_id
        self.cron_schedules = cron_schedules
        self.schedule_id = schedule_id
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RoleDefinition(Model):
    """RoleDefinition.

    :param description:
    :type description: str
    :param role_name:
    :type role_name: str
    """

    _attribute_map = {
        'description': {'key': 'description', 'type': 'str'},
        'role_name': {'key': 'roleName', 'type': 'str'},
    }

    def __init__(self, *, description: str=None, role_name: str=None, **kwargs) -> None:
        super(RoleDefinition, self).__init__(**kwargs)
        self.description = description
        self.role_name = role_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrialInfo(Model):
    """The information for a trial instance.

    :param help_sections_visited: Gets the list of section were helped is
     disabled
    :type help_sections_visited: list[str]
    :param has_completed_initial_ingestion: Gets a value indicating whether
     the initial ingestion has completed
    :type has_completed_initial_ingestion: bool
    :param trial_activated: Gets a value indicating whether the trial
     environment is activated or not
    :type trial_activated: bool
    """

    _attribute_map = {
        'help_sections_visited': {'key': 'helpSectionsVisited', 'type': '[str]'},
        'has_completed_initial_ingestion': {'key': 'hasCompletedInitialIngestion', 'type': 'bool'},
        'trial_activated': {'key': 'trialActivated', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(TrialInfo, self).__init__(**kwargs)
        self.help_sections_visited = kwargs.get('help_sections_visited', None)
        self.has_completed_initial_ingestion = kwargs.get('has_completed_initial_ingestion', None)
        self.trial_activated = kwargs.get('trial_activated', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureAggregate(Model):
    """Represents an aggregate.

    :param operation: Possible values include: 'sum', 'avg', 'min', 'max',
     'count', 'countDistinct', 'first', 'last', 'argMax', 'argMin'
    :type operation: str or ~dynamics.customerinsights.api.models.enum
    :param field: Gets the field on which the aggregate operation is applied
    :type field: str
    :param alias: Gets the alias for the field
    :type alias: str
    :param display_name: Gets the display name for the aggregate
    :type display_name: str
    :param order: Gets the order for the aggregate
    :type order: int
    :param operation_scope: Possible values include: 'rollup'
    :type operation_scope: str or ~dynamics.customerinsights.api.models.enum
    :param aggregates: Gets list of aggregates of the measure.
    :type aggregates:
     list[~dynamics.customerinsights.api.models.MeasureAggregate]
    :param is_included: Gets a value indicating whether to display the field
     in results. Default value: False .
    :type is_included: bool
    """

    _attribute_map = {
        'operation': {'key': 'operation', 'type': 'str'},
        'field': {'key': 'field', 'type': 'str'},
        'alias': {'key': 'alias', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'order': {'key': 'order', 'type': 'int'},
        'operation_scope': {'key': 'operationScope', 'type': 'str'},
        'aggregates': {'key': 'aggregates', 'type': '[MeasureAggregate]'},
        'is_included': {'key': 'isIncluded', 'type': 'bool'},
    }

    def __init__(self, *, operation=None, field: str=None, alias: str=None, display_name: str=None, order: int=None, operation_scope=None, aggregates=None, is_included: bool=False, **kwargs) -> None:
        super(MeasureAggregate, self).__init__(**kwargs)
        self.operation = operation
        self.field = field
        self.alias = alias
        self.display_name = display_name
        self.order = order
        self.operation_scope = operation_scope
        self.aggregates = aggregates
        self.is_included = is_included



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ResourceMetadata(Model):
    """Represents a Resource metadata.

    :param kind: Possible values include: 'bearerAuthenticationConnection',
     'sshKeyAuthenticationConnection', 'apiKeyAuthenticationConnection',
     'basicAuthenticationConnection', 'firstPartyADConnection',
     'amazonS3Connection', 'adlsGen2', 'd365Sales', 'd365Marketing',
     'attachCds', 'ftp', 'facebookAds', 'amlWorkspace', 'mlStudioWebservice',
     'adRoll', 'rollWorks', 'constantContact', 'campaignMonitor', 'http',
     'dotDigital', 'mailchimp', 'linkedIn', 'googleAds', 'marketo',
     'microsoftAds', 'omnisend', 'sendGrid', 'sendinblue', 'activeCampaign',
     'autopilot', 'klaviyo', 'snapchat', 'powerBI', 'azureSql', 'synapse'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param resource_id: Gets the Id of the resource.
    :type resource_id: str
    :param operation_id: Gets the Id of the operation being performed on the
     resource.
    :type operation_id: str
    :param name: Gets the Name of the resource.
    :type name: str
    :param description: Gets the Description of the resource.
    :type description: str
    :param key_vault_metadata_id: MetadataId for Linked KeyVaultMetadata
    :type key_vault_metadata_id: str
    :param mapped_secrets:
    :type mapped_secrets:
     ~dynamics.customerinsights.api.models.MappedSecretMetadata
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'resource_id': {'key': 'resourceId', 'type': 'str'},
        'operation_id': {'key': 'operationId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'key_vault_metadata_id': {'key': 'keyVaultMetadataId', 'type': 'str'},
        'mapped_secrets': {'key': 'mappedSecrets', 'type': 'MappedSecretMetadata'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ResourceMetadata, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.resource_id = kwargs.get('resource_id', None)
        self.operation_id = kwargs.get('operation_id', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.key_vault_metadata_id = kwargs.get('key_vault_metadata_id', None)
        self.mapped_secrets = kwargs.get('mapped_secrets', None)
        self.version = kwargs.get('version', None)
        self.updated_by = kwargs.get('updated_by', None)
        self.updated_utc = kwargs.get('updated_utc', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_utc = kwargs.get('created_utc', None)
        self.instance_id = kwargs.get('instance_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IRelationshipMetadata(Model):
    """Represents Relationship Metadata.

    :param name: Unique Name for relationship
    :type name: str
    :param friendly_name: User Friendly Name for relationship
    :type friendly_name: str
    :param from_attribute:
    :type from_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param to_attribute:
    :type to_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param relationship_type: Possible values include:
     'singleKeyRelationshipOrigin', 'singleKeyRelationshipDestination',
     'dataSourceLineageOrigin', 'dataSourceLineageDestination'
    :type relationship_type: str or ~dynamics.customerinsights.api.models.enum
    :param data_source_entity:
    :type data_source_entity:
     ~dynamics.customerinsights.api.models.IEntityMetadata
    :param data_source_mapping_attributes: List of data source mapping
     attributes
    :type data_source_mapping_attributes:
     list[~dynamics.customerinsights.api.models.IAttributeMetadata]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'from_attribute': {'key': 'fromAttribute', 'type': 'IAttributeMetadata'},
        'to_attribute': {'key': 'toAttribute', 'type': 'IAttributeMetadata'},
        'relationship_type': {'key': 'relationshipType', 'type': 'str'},
        'data_source_entity': {'key': 'dataSourceEntity', 'type': 'IEntityMetadata'},
        'data_source_mapping_attributes': {'key': 'dataSourceMappingAttributes', 'type': '[IAttributeMetadata]'},
    }

    def __init__(self, **kwargs):
        super(IRelationshipMetadata, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.friendly_name = kwargs.get('friendly_name', None)
        self.from_attribute = kwargs.get('from_attribute', None)
        self.to_attribute = kwargs.get('to_attribute', None)
        self.relationship_type = kwargs.get('relationship_type', None)
        self.data_source_entity = kwargs.get('data_source_entity', None)
        self.data_source_mapping_attributes = kwargs.get('data_source_mapping_attributes', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RelationshipMetadata(Model):
    """Represents a Relationship.

    :param friendly_name: Gets the friendly name of the relationship.
    :type friendly_name: str
    :param name: Gets the unique name for relationship
    :type name: str
    :param description: Gets the description for relationship
    :type description: str
    :param relationship_type: Possible values include:
     'singleKeyRelationshipOrigin', 'singleKeyRelationshipDestination',
     'dataSourceLineageOrigin', 'dataSourceLineageDestination'
    :type relationship_type: str or ~dynamics.customerinsights.api.models.enum
    :param from_attribute_name: Gets the name of the foreign key reference
     attribute that this relationship originates from.
    :type from_attribute_name: str
    :param from_entity_name: Gets the name of the entity this relationship
     originates from.
    :type from_entity_name: str
    :param to_attribute_name: Gets the name of the foreign key attribute that
     this relationship points to.
    :type to_attribute_name: str
    :param to_entity_name: Gets the name of the entity this relationship
     points to.
    :type to_entity_name: str
    :param cardinality: Possible values include: 'oneToMany', 'oneToOne',
     'manyToOne'
    :type cardinality: str or ~dynamics.customerinsights.api.models.enum
    :param source: Possible values include: 'user', 'system', 'inferred'
    :type source: str or ~dynamics.customerinsights.api.models.enum
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'relationship_type': {'key': 'relationshipType', 'type': 'str'},
        'from_attribute_name': {'key': 'fromAttributeName', 'type': 'str'},
        'from_entity_name': {'key': 'fromEntityName', 'type': 'str'},
        'to_attribute_name': {'key': 'toAttributeName', 'type': 'str'},
        'to_entity_name': {'key': 'toEntityName', 'type': 'str'},
        'cardinality': {'key': 'cardinality', 'type': 'str'},
        'source': {'key': 'source', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, friendly_name: str=None, name: str=None, description: str=None, relationship_type=None, from_attribute_name: str=None, from_entity_name: str=None, to_attribute_name: str=None, to_entity_name: str=None, cardinality=None, source=None, version: int=None, updated_by: str=None, updated_utc=None, created_by: str=None, created_utc=None, instance_id: str=None, **kwargs) -> None:
        super(RelationshipMetadata, self).__init__(**kwargs)
        self.friendly_name = friendly_name
        self.name = name
        self.description = description
        self.relationship_type = relationship_type
        self.from_attribute_name = from_attribute_name
        self.from_entity_name = from_entity_name
        self.to_attribute_name = to_attribute_name
        self.to_entity_name = to_entity_name
        self.cardinality = cardinality
        self.source = source
        self.version = version
        self.updated_by = updated_by
        self.updated_utc = updated_utc
        self.created_by = created_by
        self.created_utc = created_utc
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataErrorDetail(Model):
    """ODataErrorDetail.

    :param error_code:
    :type error_code: str
    :param message:
    :type message: str
    :param target:
    :type target: str
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
    }

    def __init__(self, *, error_code: str=None, message: str=None, target: str=None, **kwargs) -> None:
        super(ODataErrorDetail, self).__init__(**kwargs)
        self.error_code = error_code
        self.message = message
        self.target = target



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LogMessage(Model):
    """LogMessage.

    :param location:
    :type location: ~dynamics.customerinsights.api.models.SourceLocation
    :param message:
    :type message: str
    """

    _attribute_map = {
        'location': {'key': 'location', 'type': 'SourceLocation'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, *, location=None, message: str=None, **kwargs) -> None:
        super(LogMessage, self).__init__(**kwargs)
        self.location = location
        self.message = message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PbiProvisioningConfig(Model):
    """The information on how authentication needs to happen for embedded
    resources.

    :param use_client_login_for_reports: Indicates whether we need to use
     client login for Pbi Embedded
    :type use_client_login_for_reports: bool
    :param use_client_login_for_pq: Indicates whether we need to use client
     login for PQ Embedded
    :type use_client_login_for_pq: bool
    :param capacity_id: Power BI Capacity id
    :type capacity_id: str
    """

    _attribute_map = {
        'use_client_login_for_reports': {'key': 'useClientLoginForReports', 'type': 'bool'},
        'use_client_login_for_pq': {'key': 'useClientLoginForPQ', 'type': 'bool'},
        'capacity_id': {'key': 'capacityId', 'type': 'str'},
    }

    def __init__(self, *, use_client_login_for_reports: bool=None, use_client_login_for_pq: bool=None, capacity_id: str=None, **kwargs) -> None:
        super(PbiProvisioningConfig, self).__init__(**kwargs)
        self.use_client_login_for_reports = use_client_login_for_reports
        self.use_client_login_for_pq = use_client_login_for_pq
        self.capacity_id = capacity_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StringInfo(Model):
    """StringInfo.

    :param value:
    :type value: str
    :param key: Possible values include:
     'activityMappingDuplicateMappingOnEntity', 'activityMappingEmptyInput',
     'activityMappingInvalidKeyAttribute',
     'activityMappingInvalidRelationshipAttribute',
     'activityMappingInvalidStartEndTimeField',
     'activityMappingInvalidStartTimeFieldValue', 'apiInternalError',
     'apiVersionNotSupported', 'authEmptyAuthorizationCode',
     'authEmptyAuthorizationCodeError', 'authEmptyBearerToken',
     'authEmptyBearerTokenError', 'authEmptyRedirect', 'authEmptyRedirectUrl',
     'authEmptyRefreshToken', 'authEmptyState', 'authInvalidApp',
     'authInvalidAppType', 'authInvalidToken', 'authUserHasC360LicenseError',
     'configurationControllerMissingInput', 'customer360ApiInvalidIdentity',
     'customer360ApiInvalidTenantIdClaims',
     'customer360ApiInvalidUserIdClaims', 'dataRefreshInvalidScheduleRequest',
     'dataSourceCreateAlreadyExistError', 'dataSourceModelAlreadyExistError',
     'dataSourceDataSourceCanNotDelete', 'dataSourceDataSourceDeleted',
     'dataSourceDataSourceNotFound', 'dataSourceDuplicateDataSourceName',
     'dataSourceEmptyDataSource', 'dataSourceEmptyDataSourceName',
     'dataSourceEmptyDataSourceNameError', 'dataSourceEmptyAttributeError',
     'dataLakeAccountInvalidError', 'dataLakeSecretInvalidError',
     'dataSourceModelNotFoundError', 'modelDataTypeError',
     'modelDataConvertError', 'resourceMetadataNotFoundError',
     'dataSourceInactiveInstance', 'dataSourceInstanceNotFound',
     'dataSourceCreationFailed', 'dataSourceInvalidDataSourceName',
     'dataSourceInvalidDataSourceNameCharacter',
     'dataSourceInvalidEntityNames', 'dataSourceMetadataExceedsLimit',
     'dataSourceNotFound', 'dataSourceNotProvisioned',
     'dataSourceRefreshTimeout', 'dataSourceUpdateAlreadyExistError',
     'dataSourceUpdateDependenciesError', 'datasourceIngestionUnexpectedError',
     'dynamics365EmptyHeader', 'entityDataControllerContentType',
     'entityMetadataCanNotMarkAttribute', 'entityMetadataCanNotUpdateEntity',
     'entityMetadataCanNotUpdateEntityOfActivityType',
     'entityMetadataForAttributeNotFoundForEntity',
     'entityMetadataNotFoundForEntity', 'failedToSubmiProfileStoreJob',
     'gdprDeleteOldSnapshotsConfiguratonError',
     'gdprDeleteOldSnapshotsNonC360DataflowsError', 'graphApiEmptySearchTerm',
     'graphApiPrincipalIdMissingInRequest', 'graphApiPrincipalIdsExceedslimit',
     'graphApiPrincipalIdsExceedslimitError', 'graphApiTopLimitError',
     'graphApiGroupDirectoryInfoFailed', 'graphApiUserDirectoryInfoFailed',
     'instanceNoAssignmentsInRequest', 'instanceUserSettingsMissing',
     'instancePreferredLanguageMissing',
     'instancePreferredRegionalFormatMissing', 'invalidDataSourceType',
     'invocationBadRequestInReadingHeaderInfo', 'invocationFailedBindToMethod',
     'invocationUnsupportedMediaType',
     'measuresProcessingOrchestrationSkipMeasuresAndNotify',
     'nullOrEmptyInstanceId', 'offlineGraphIngestionOrchestrationNotify',
     'segmentEvaluationOrchestrationNotify',
     'profileStoreIngestionFailedWithJobInfo',
     'profileStoreIngestionOrchestrationFailed',
     'profileStoreOrchestrationSuccessful',
     'publicMetadataControllerAnonymousType', 'rbacAADDirectoryObjectNotFound',
     'rbacCanNotRevokePermissionFromInstance',
     'rbacDeletedRoleAssignmentsFromUser', 'rbacInvalidRole',
     'rbacRoleIsNotValid', 'rbacUnsupportedPrincipalType', 'rbacUserNotFound',
     'refreshBackgroundTaskRunningError', 'refreshConflationCancelled',
     'refreshConflationMetadataNotFound', 'refreshConflationJobFailed',
     'refreshEnrichmentMetadataNotFound', 'refreshEnrichmentMisconfigured',
     'refreshEnrichmentRequestExceeded', 'refreshEnrichmentRequestThrottling',
     'refreshExportCancelled', 'refreshExportCompleted', 'refreshExportFailed',
     'refreshExportRequestThrottling', 'refreshExportSkipped',
     'refreshMatchRequestThrotling',
     'refreshMeasuresEvaluationRequestThrottling',
     'refreshMergeRequestThrotling', 'refreshPrerequisitesUnmetError',
     'refreshRunningOrchestrationNotFound', 'resourceBuilderFailure',
     'segmentAdvancedEditorNotEnabled', 'staleMatchMetadataError',
     'staleMatchRunError', 'testName', 'measuresProcessingOrchestrationFailed',
     'measuresProcessingOrchestrationFailedV2',
     'offlineGraphIngestionOrchestrationFailed',
     'segmentEvaluationOrchestrationFailed', 'matchMergeOrchestrationFailed',
     'refreshMatchPairsEntityDoesNotExist',
     'invalidSegmentDefinitionErrorMessage', 'clauseForNextRefresh',
     'refreshIntelligenceCancelled', 'refreshIntelligenceCompleted',
     'refreshIntelligenceFailed', 'refreshIntelligenceSkipped',
     'refreshIntelligenceDisabled', 'refreshConflationConfigurationNotFound',
     'conflationPlanInvalid', 'conflationMetadataNotFoundForEntity',
     'conflationMetadataNotFoundForColumn', 'conflationConfigurationInvalid',
     'conflationUnexpectedError', 'matchPairsEntityDataMissing',
     'matchPairsEntityNotExist', 'conflationResolutionInvalid',
     'intelligenceUnsupportedDiscoverySource',
     'refreshDataPreparationCancelled',
     'refreshDataPreparationRequestThrottling', 'refreshDataPreparationFailed',
     'bapNotMapped', 'bapCannotCreateEnvironment',
     'bapInvalidEnvironmentDisplayNameLength',
     'bapInvalidEnvironmentDisplayName', 'bapInvalidEnvironmentLocation',
     'bapInvalidEnvironmentSku', 'bapInvalidEnvironment',
     'bapInvalidTenantEnvironmentLimit', 'bapInvalidUserEnvironmentLimit',
     'dataSourceIngestionCancelled', 'dataSourceIngestionSkippedNoEntities',
     'genericPredictionEntitiesNotAvailable',
     'genericPredictionEntityPartitionsNotAvailable',
     'genericPredictionEntityWithLabelAttributeNotAvailable',
     'genericPredictionAttributesNotAvailable',
     'invalidJarvisEntityCreationErrorMessage',
     'activityIngestionActivityIdNotFound',
     'activityIngestionActivityTimeNotFound',
     'activityIngestionIncorrectMinViewFields',
     'activityIngestionNoJarvisColumnMapping', 'activityIngestionNoPrimaryKey',
     'activityIngestionNoSourceStream',
     'activityIngestionNoSourceStreamWithCorrectActivityName',
     'activityIngestionNoStartOrEndTime',
     'activityIngestionRangeIndexNotFound',
     'activityIngestionUniqueSourceStream', 'entityNoPrimaryKey',
     'invalidSegmentAdvancedSegCreateInInvalidState', 'invalidSegmentFormat',
     'invalidSegmentNameExists', 'inavlidSegmentType',
     'inavlidSegmentValidationDisabled', 'invalidSegmentNameConflict',
     'invalidSegmentNoExistingSegWithName', 'invalidSegmentSegNotFound',
     'invalidSegmentValidationNotAllowedForState',
     'invalidSegmentValidationNotAllowedForType', 'segmentNotFound',
     'dataSourceEmptyResourceIdError', 'invalidOrganizationUrl',
     'enablingCdsEntitiesFailed',
     'dataSourceIngestionSkippedForMissingCdsModelJsonPath',
     'dataSourceIngestionSkippedForCdsModelIncomplete',
     'missingOrganizationUrl', 'searchStoreUnavailable',
     'profileStoreUnavailable', 'unsupportedInsightType',
     'invalidInsightInputGeneric', 'invalidMalformedInsightInputPayload',
     'invalidInsightInputMissingName'
    :type key: str or ~dynamics.customerinsights.api.models.enum
    :param args:
    :type args: list[str]
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'key': {'key': 'key', 'type': 'str'},
        'args': {'key': 'args', 'type': '[str]'},
    }

    def __init__(self, *, value: str=None, key=None, args=None, **kwargs) -> None:
        super(StringInfo, self).__init__(**kwargs)
        self.value = value
        self.key = key
        self.args = args



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttributeDataProfile(Model):
    """Attribute data profile.

    :param value_counts: Represents Distribution of the top 100 values.
    :type value_counts: list[~dynamics.customerinsights.api.models.ValueCount]
    :param histogram: Represents histogram information Ordered from smallest
     to largest bin.
    :type histogram: list[~dynamics.customerinsights.api.models.HistogramBin]
    :param qualified_entity_name: Qualified entity name.
    :type qualified_entity_name: str
    :param attribute_name: Attribute name.
    :type attribute_name: str
    :param min: Minimum value.
    :type min: object
    :param max: Maximum value.
    :type max: object
    :param count: Total row count.
    :type count: long
    :param missing_count: Row count of missing values.
    :type missing_count: long
    :param error_count: Number of error values.
    :type error_count: long
    :param quantiles:
    :type quantiles: ~dynamics.customerinsights.api.models.Quantiles
    :param moments:
    :type moments: ~dynamics.customerinsights.api.models.Moments
    :param unique_value_count: Number of unique values.
    :type unique_value_count: long
    :param profiling_date: Profiling date
    :type profiling_date: datetime
    :param is_suggested_primary_key: Represents a value indicating whether
     this attribute can be used as a primary key of the entity
    :type is_suggested_primary_key: bool
    :param check_if_exact_stats: Represents a value indicating whether we
     calculate exact or approx stats
    :type check_if_exact_stats: object
    """

    _attribute_map = {
        'value_counts': {'key': 'valueCounts', 'type': '[ValueCount]'},
        'histogram': {'key': 'histogram', 'type': '[HistogramBin]'},
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'attribute_name': {'key': 'attributeName', 'type': 'str'},
        'min': {'key': 'min', 'type': 'object'},
        'max': {'key': 'max', 'type': 'object'},
        'count': {'key': 'count', 'type': 'long'},
        'missing_count': {'key': 'missingCount', 'type': 'long'},
        'error_count': {'key': 'errorCount', 'type': 'long'},
        'quantiles': {'key': 'quantiles', 'type': 'Quantiles'},
        'moments': {'key': 'moments', 'type': 'Moments'},
        'unique_value_count': {'key': 'uniqueValueCount', 'type': 'long'},
        'profiling_date': {'key': 'profilingDate', 'type': 'iso-8601'},
        'is_suggested_primary_key': {'key': 'isSuggestedPrimaryKey', 'type': 'bool'},
        'check_if_exact_stats': {'key': 'checkIfExactStats', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(AttributeDataProfile, self).__init__(**kwargs)
        self.value_counts = kwargs.get('value_counts', None)
        self.histogram = kwargs.get('histogram', None)
        self.qualified_entity_name = kwargs.get('qualified_entity_name', None)
        self.attribute_name = kwargs.get('attribute_name', None)
        self.min = kwargs.get('min', None)
        self.max = kwargs.get('max', None)
        self.count = kwargs.get('count', None)
        self.missing_count = kwargs.get('missing_count', None)
        self.error_count = kwargs.get('error_count', None)
        self.quantiles = kwargs.get('quantiles', None)
        self.moments = kwargs.get('moments', None)
        self.unique_value_count = kwargs.get('unique_value_count', None)
        self.profiling_date = kwargs.get('profiling_date', None)
        self.is_suggested_primary_key = kwargs.get('is_suggested_primary_key', None)
        self.check_if_exact_stats = kwargs.get('check_if_exact_stats', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IEntityMetadata(Model):
    """Represents Entity Metadata.

    :param name: Gets the name of the entity. eg: Contact.
    :type name: str
    :param qualified_entity_name: Gets the unqiue logical name for the entity
     If entity is from a datasource, QualifiedEntityName =
     datasourceId_EntityName eg: d8d3b26a-a8ad-42f7-901e-f7f745003a84_Contact.
     If entity is generated by C360, QualifiedEntityName = EntityName eg:
     Contact.
    :type qualified_entity_name: str
    :param data_source_name: Gets the datasource name of this entity, if no
     data source, return null or emptyString
    :type data_source_name: str
    :param dataflow_type: Possible values include: 'dynamics365',
     'salesforce', 'conflationSortAndRefine', 'conflationDeduplication',
     'conflationMatchPairs', 'conflationResolveConflicts', 'enriched', 'kpi',
     'powerQuery', 'dataPreparation', 'intelligence', 'unifiedActivity',
     'segmentation', 'ingestion', 'attachCdm', 'genericPrediction',
     'attachCds', 'unknown', 'powerPlatform', 'datahub', 'insights',
     'derivedEntity', 'powerPlatformSource', 'powerPlatformBYDL',
     'powerPlatformBYDLSource', 'semanticActivity', 'segmentMembership',
     'firstParty', 'hierarchy', 'contact', 'semanticEntity', 'attachSynapse',
     'transform'
    :type dataflow_type: str or ~dynamics.customerinsights.api.models.enum
    :param should_use_spark_sas_auth: Gets a value indicating whether Sas Auth
     is used for the entity.
    :type should_use_spark_sas_auth: bool
    :param datasource_id: Gets the original datasourceid of this entity, if no
     data source, return null or emptyString
    :type datasource_id: str
    :param entity_type: Possible values include: 'unspecified', 'profile',
     'conflationMap', 'activity', 'aggregateKpi', 'profileKpi',
     'unifiedActivity', 'segment', 'intelligence', 'genericPrediction',
     'enrichment', 'insights', 'derivedEntity', 'corrupt', 'selfConflation',
     'conflationManualReview', 'selfConflationManualReview',
     'semanticActivity', 'segmentMembership', 'hierarchy', 'dataLineage',
     'transform', 'semanticEntity'
    :type entity_type: str or ~dynamics.customerinsights.api.models.enum
    :param attributes: Gets entity attributes.
    :type attributes:
     list[~dynamics.customerinsights.api.models.IAttributeMetadata]
    :param keys: Gets the keys of the entity.
    :type keys:
     list[list[~dynamics.customerinsights.api.models.IAttributeMetadata]]
    :param relationships: Gets entity relationships.
    :type relationships:
     list[~dynamics.customerinsights.api.models.IRelationshipMetadata]
    :param timestamp_attribute:
    :type timestamp_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param incremental_attribute:
    :type incremental_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param semantic_type: Possible values include: 'Account', 'AccountLeads',
     'ActivityParty', 'ActivityPointer', 'Annotation', 'Appointment',
     'BusinessUnit', 'Campaign', 'CampaignActivity', 'CampaignItem',
     'CampaignResponse', 'Characteristic', 'Competitor', 'CompetitorAddress',
     'CompetitorProduct', 'Connection', 'ConnectionRole', 'Contact',
     'Contract', 'ContractDetail', 'Customer', 'CustomerAddress',
     'CustomerRelationship', 'Discount', 'DiscountType', 'Email',
     'Entitlement', 'Equipment', 'Fax', 'Feedback', 'Goal', 'Incident',
     'Invoice', 'InvoiceDetail', 'KbArticle', 'KnowledgeArticle', 'Lead',
     'LeadAddress', 'Letter', 'Metric', 'Opportunity', 'Organization', 'Owner',
     'PhoneCall', 'Position', 'PriceLevel', 'Product', 'Quote', 'RatingModel',
     'Resource', 'ResourceGroup', 'SalesLiterature', 'SalesOrder', 'Service',
     'ServiceAppointment', 'Site', 'SLA', 'SocialActivity', 'SocialProfile',
     'SystemUser', 'Task', 'Team', 'Territory', 'UoM'
    :type semantic_type: str or ~dynamics.customerinsights.api.models.enum
    :param refresh_time: Gets last refresh time for entity.
    :type refresh_time: datetime
    :param partitions: Gets entity data partitions.
    :type partitions:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param incremental_upsert_partitions: Gets entity incremental upsert data
     partitions.
    :type incremental_upsert_partitions:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param incremental_delete_partitions: Gets entity incremental delete data
     partitions.
    :type incremental_delete_partitions:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param full_partitions_parquet: Gets entity data parquet partitions.
    :type full_partitions_parquet:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param incremental_upsert_partitions_parquet: Gets entity incremental
     upsert data parquet partitions.
    :type incremental_upsert_partitions_parquet:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param incremental_delete_partitions_parquet: Gets entity incremental
     delete data parquet partitions.
    :type incremental_delete_partitions_parquet:
     list[~dynamics.customerinsights.api.models.PartitionMetadata]
    :param annotations: Gets base entity name
    :type annotations: list[~dynamics.customerinsights.api.models.Annotation]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'data_source_name': {'key': 'dataSourceName', 'type': 'str'},
        'dataflow_type': {'key': 'dataflowType', 'type': 'str'},
        'should_use_spark_sas_auth': {'key': 'shouldUseSparkSasAuth', 'type': 'bool'},
        'datasource_id': {'key': 'datasourceId', 'type': 'str'},
        'entity_type': {'key': 'entityType', 'type': 'str'},
        'attributes': {'key': 'attributes', 'type': '[IAttributeMetadata]'},
        'keys': {'key': 'keys', 'type': '[[IAttributeMetadata]]'},
        'relationships': {'key': 'relationships', 'type': '[IRelationshipMetadata]'},
        'timestamp_attribute': {'key': 'timestampAttribute', 'type': 'IAttributeMetadata'},
        'incremental_attribute': {'key': 'incrementalAttribute', 'type': 'IAttributeMetadata'},
        'semantic_type': {'key': 'semanticType', 'type': 'str'},
        'refresh_time': {'key': 'refreshTime', 'type': 'iso-8601'},
        'partitions': {'key': 'partitions', 'type': '[PartitionMetadata]'},
        'incremental_upsert_partitions': {'key': 'incrementalUpsertPartitions', 'type': '[PartitionMetadata]'},
        'incremental_delete_partitions': {'key': 'incrementalDeletePartitions', 'type': '[PartitionMetadata]'},
        'full_partitions_parquet': {'key': 'fullPartitionsParquet', 'type': '[PartitionMetadata]'},
        'incremental_upsert_partitions_parquet': {'key': 'incrementalUpsertPartitionsParquet', 'type': '[PartitionMetadata]'},
        'incremental_delete_partitions_parquet': {'key': 'incrementalDeletePartitionsParquet', 'type': '[PartitionMetadata]'},
        'annotations': {'key': 'annotations', 'type': '[Annotation]'},
    }

    def __init__(self, **kwargs):
        super(IEntityMetadata, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.qualified_entity_name = kwargs.get('qualified_entity_name', None)
        self.data_source_name = kwargs.get('data_source_name', None)
        self.dataflow_type = kwargs.get('dataflow_type', None)
        self.should_use_spark_sas_auth = kwargs.get('should_use_spark_sas_auth', None)
        self.datasource_id = kwargs.get('datasource_id', None)
        self.entity_type = kwargs.get('entity_type', None)
        self.attributes = kwargs.get('attributes', None)
        self.keys = kwargs.get('keys', None)
        self.relationships = kwargs.get('relationships', None)
        self.timestamp_attribute = kwargs.get('timestamp_attribute', None)
        self.incremental_attribute = kwargs.get('incremental_attribute', None)
        self.semantic_type = kwargs.get('semantic_type', None)
        self.refresh_time = kwargs.get('refresh_time', None)
        self.partitions = kwargs.get('partitions', None)
        self.incremental_upsert_partitions = kwargs.get('incremental_upsert_partitions', None)
        self.incremental_delete_partitions = kwargs.get('incremental_delete_partitions', None)
        self.full_partitions_parquet = kwargs.get('full_partitions_parquet', None)
        self.incremental_upsert_partitions_parquet = kwargs.get('incremental_upsert_partitions_parquet', None)
        self.incremental_delete_partitions_parquet = kwargs.get('incremental_delete_partitions_parquet', None)
        self.annotations = kwargs.get('annotations', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OnDemandJobRequest(Model):
    """OnDemandJobRequest.

    :param graph_name:
    :type graph_name: str
    :param operation_type: Possible values include: 'none', 'ingestion',
     'derivedEntity', 'hierarchy', 'dataPreparation', 'map',
     'realtimeM3Search', 'match', 'merge', 'profileStore', 'search',
     'activity', 'contact', 'attributeMeasures', 'entityMeasures', 'measures',
     'segmentation', 'segmentMembership', 'enrichment', 'preEnrichment',
     'transform', 'intelligence', 'aiBuilder', 'insights', 'export',
     'modelManagement', 'relationship', 'roleAssignment', 'analysis',
     'semanticEntity', 'all'
    :type operation_type: str or ~dynamics.customerinsights.api.models.enum
    :param submission_kind: Possible values include: 'onDemand', 'scheduled'
    :type submission_kind: str or ~dynamics.customerinsights.api.models.enum
    :param job_type: Possible values include: 'full', 'incremental'
    :type job_type: str or ~dynamics.customerinsights.api.models.enum
    :param identifiers:
    :type identifiers: list[str]
    :param force_run_requested:
    :type force_run_requested: bool
    :param input_refresh_mode: Possible values include:
     'FailedOrModifiedRecursive', 'FailedRecursive', 'FailedOrModified',
     'Failed', 'None'
    :type input_refresh_mode: str or
     ~dynamics.customerinsights.api.models.enum
    :param options:
    :type options: ~dynamics.customerinsights.api.models.GraphJobOptions
    """

    _attribute_map = {
        'graph_name': {'key': 'graphName', 'type': 'str'},
        'operation_type': {'key': 'operationType', 'type': 'str'},
        'submission_kind': {'key': 'submissionKind', 'type': 'str'},
        'job_type': {'key': 'jobType', 'type': 'str'},
        'identifiers': {'key': 'identifiers', 'type': '[str]'},
        'force_run_requested': {'key': 'forceRunRequested', 'type': 'bool'},
        'input_refresh_mode': {'key': 'inputRefreshMode', 'type': 'str'},
        'options': {'key': 'options', 'type': 'GraphJobOptions'},
    }

    def __init__(self, **kwargs):
        super(OnDemandJobRequest, self).__init__(**kwargs)
        self.graph_name = kwargs.get('graph_name', None)
        self.operation_type = kwargs.get('operation_type', None)
        self.submission_kind = kwargs.get('submission_kind', None)
        self.job_type = kwargs.get('job_type', None)
        self.identifiers = kwargs.get('identifiers', None)
        self.force_run_requested = kwargs.get('force_run_requested', None)
        self.input_refresh_mode = kwargs.get('input_refresh_mode', None)
        self.options = kwargs.get('options', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureLinkedEntity(Model):
    """Represents the base linked entity.

    :param kind: Possible values include: 'base', 'join', 'scalar'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param entity: Gets the name of the entity.
    :type entity: str
    :param alias: Gets the alias of the entity.
    :type alias: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'entity': {'key': 'entity', 'type': 'str'},
        'alias': {'key': 'alias', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeasureLinkedEntity, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.entity = kwargs.get('entity', None)
        self.alias = kwargs.get('alias', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QueryMetadata(Model):
    """QueryMetadata.

    :param query_id:
    :type query_id: str
    :param query_name:
    :type query_name: str
    :param query_group_id:
    :type query_group_id: str
    :param entity_name:
    :type entity_name: str
    :param load_enabled:
    :type load_enabled: bool
    """

    _attribute_map = {
        'query_id': {'key': 'queryId', 'type': 'str'},
        'query_name': {'key': 'queryName', 'type': 'str'},
        'query_group_id': {'key': 'queryGroupId', 'type': 'str'},
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'load_enabled': {'key': 'loadEnabled', 'type': 'bool'},
    }

    def __init__(self, *, query_id: str=None, query_name: str=None, query_group_id: str=None, entity_name: str=None, load_enabled: bool=None, **kwargs) -> None:
        super(QueryMetadata, self).__init__(**kwargs)
        self.query_id = query_id
        self.query_name = query_name
        self.query_group_id = query_group_id
        self.entity_name = entity_name
        self.load_enabled = load_enabled



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmailSubscriptionMetadata(Model):
    """Represents a email subscription for the instance.

    :param email_subscription: Possible values include: 'finishData'
    :type email_subscription: str or
     ~dynamics.customerinsights.api.models.enum
    :param email: Gets the email for the subscription.
    :type email: str
    :param status: Gets the current status for the subscription.
    :type status: str
    """

    _attribute_map = {
        'email_subscription': {'key': 'emailSubscription', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EmailSubscriptionMetadata, self).__init__(**kwargs)
        self.email_subscription = kwargs.get('email_subscription', None)
        self.email = kwargs.get('email', None)
        self.status = kwargs.get('status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentQueryStat(Model):
    """Represents a Segment Stat.

    :param rowset_stat: Gets a list of Rowset Stat.
    :type rowset_stat:
     list[~dynamics.customerinsights.api.models.SegmentRowsetStat]
    """

    _attribute_map = {
        'rowset_stat': {'key': 'rowsetStat', 'type': '[SegmentRowsetStat]'},
    }

    def __init__(self, *, rowset_stat=None, **kwargs) -> None:
        super(SegmentQueryStat, self).__init__(**kwargs)
        self.rowset_stat = rowset_stat



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PartitionMetadata(Model):
    """Represents a DCI entity data partition.

    :param name: Gets the name of the data partition
    :type name: str
    :param location: Gets the uri location of the data
    :type location: str
    :param refresh_time: Gets the refresh time of the data partition
    :type refresh_time: datetime
    :param file_format_settings:
    :type file_format_settings: object
    :param is_ci_generated: Gets a value indicating whether a partition is CI
     Generated or not.
    :type is_ci_generated: bool
    :param force_sas_auth: Gets a value indicating whether a partition need to
     be forced for SAS authentication.
    :type force_sas_auth: bool
    :param has_header: Flag to represent header presence (if any)
    :type has_header: bool
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'refresh_time': {'key': 'refreshTime', 'type': 'iso-8601'},
        'file_format_settings': {'key': 'fileFormatSettings', 'type': 'object'},
        'is_ci_generated': {'key': 'isCIGenerated', 'type': 'bool'},
        'force_sas_auth': {'key': 'forceSasAuth', 'type': 'bool'},
        'has_header': {'key': 'hasHeader', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(PartitionMetadata, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.location = kwargs.get('location', None)
        self.refresh_time = kwargs.get('refresh_time', None)
        self.file_format_settings = kwargs.get('file_format_settings', None)
        self.is_ci_generated = kwargs.get('is_ci_generated', None)
        self.force_sas_auth = kwargs.get('force_sas_auth', None)
        self.has_header = kwargs.get('has_header', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentationQuery(Model):
    """Represent a Segment Query.

    :param type: Possible values include: 'structured', 'manual'
    :type type: str or ~dynamics.customerinsights.api.models.enum
    :param projections: Gets list of attributes to be projected in segment.
     (DEPRECATED)
    :type projections: list[str]
    :param projected_attributes: Gets list of attributes to be projected in
     segment.
    :type projected_attributes:
     list[~dynamics.customerinsights.api.models.SegmentationProjection]
    :param rowsets: Gets list of rowsets of segment.
    :type rowsets:
     list[~dynamics.customerinsights.api.models.SegmentationRowset]
    :param segmentation_query_sql: Gets the user specified custom SQL query.
    :type segmentation_query_sql: str
    :param hierarchies: Gets a list of Hierarchies for segment query.
    :type hierarchies:
     list[~dynamics.customerinsights.api.models.HierarchyDefinition]
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'projections': {'key': 'projections', 'type': '[str]'},
        'projected_attributes': {'key': 'projectedAttributes', 'type': '[SegmentationProjection]'},
        'rowsets': {'key': 'rowsets', 'type': '[SegmentationRowset]'},
        'segmentation_query_sql': {'key': 'segmentationQuerySql', 'type': 'str'},
        'hierarchies': {'key': 'hierarchies', 'type': '[HierarchyDefinition]'},
    }

    def __init__(self, *, type=None, projections=None, projected_attributes=None, rowsets=None, segmentation_query_sql: str=None, hierarchies=None, **kwargs) -> None:
        super(SegmentationQuery, self).__init__(**kwargs)
        self.type = type
        self.projections = projections
        self.projected_attributes = projected_attributes
        self.rowsets = rowsets
        self.segmentation_query_sql = segmentation_query_sql
        self.hierarchies = hierarchies



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataError(Model):
    """ODataError.

    :param error_code:
    :type error_code: str
    :param message:
    :type message: str
    :param target:
    :type target: str
    :param details:
    :type details:
     list[~dynamics.customerinsights.api.models.ODataErrorDetail]
    :param inner_error:
    :type inner_error: ~dynamics.customerinsights.api.models.ODataInnerError
    :param instance_annotations:
    :type instance_annotations:
     list[~dynamics.customerinsights.api.models.ODataInstanceAnnotation]
    :param type_annotation:
    :type type_annotation:
     ~dynamics.customerinsights.api.models.ODataTypeAnnotation
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
        'details': {'key': 'details', 'type': '[ODataErrorDetail]'},
        'inner_error': {'key': 'innerError', 'type': 'ODataInnerError'},
        'instance_annotations': {'key': 'instanceAnnotations', 'type': '[ODataInstanceAnnotation]'},
        'type_annotation': {'key': 'typeAnnotation', 'type': 'ODataTypeAnnotation'},
    }

    def __init__(self, *, error_code: str=None, message: str=None, target: str=None, details=None, inner_error=None, instance_annotations=None, type_annotation=None, **kwargs) -> None:
        super(ODataError, self).__init__(**kwargs)
        self.error_code = error_code
        self.message = message
        self.target = target
        self.details = details
        self.inner_error = inner_error
        self.instance_annotations = instance_annotations
        self.type_annotation = type_annotation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataSourceMetadata(Model):
    """Represents metadata for a Customer Insights data source.

    :param kind: Possible values include: 'salesforce', 'dynamics365',
     'powerQuery', 'attachCdm', 'attachSynapse', 'attachCds', 'powerPlatform',
     'datahub', 'firstParty'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param is_active: Represents if still in active state
    :type is_active: bool
    :param entity_names: List of all Entity Names
    :type entity_names: list[str]
    :param entities_count:
    :type entities_count: int
    :param data_source_id: Unique identity for this object.
    :type data_source_id: str
    :param name: Unique name of the dataSource.
    :type name: str
    :param friendly_name: FriendlyName of the dataSource.
    :type friendly_name: str
    :param entity_information: Entity information, by entity name.
    :type entity_information:
     list[~dynamics.customerinsights.api.models.DatasourceEntityInformation]
    :param provisioning_state: Possible values include: 'new', 'creating',
     'active', 'createFailed', 'updateFailed', 'deleting',
     'refreshCredentials', 'resetInstanceInProgress', 'updating',
     'quickUpdate', 'deactivated'
    :type provisioning_state: str or
     ~dynamics.customerinsights.api.models.enum
    :param last_refresh: Represents the time datasource was last refreshed.
    :type last_refresh: datetime
    :param refresh_state: Possible values include: 'notUpdated', 'updated',
     'updating', 'updateFailed', 'updateCancelled'
    :type refresh_state: str or ~dynamics.customerinsights.api.models.enum
    :param incremental_refresh_properties: Incremental refresh properties for
     entities.
    :type incremental_refresh_properties:
     list[~dynamics.customerinsights.api.models.IncrementalRefreshProperties]
    :param model_json_path: Model path for CDM data source.
    :type model_json_path: str
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'entity_names': {'key': 'entityNames', 'type': '[str]'},
        'entities_count': {'key': 'entitiesCount', 'type': 'int'},
        'data_source_id': {'key': 'dataSourceId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'entity_information': {'key': 'entityInformation', 'type': '[DatasourceEntityInformation]'},
        'provisioning_state': {'key': 'provisioningState', 'type': 'str'},
        'last_refresh': {'key': 'lastRefresh', 'type': 'iso-8601'},
        'refresh_state': {'key': 'refreshState', 'type': 'str'},
        'incremental_refresh_properties': {'key': 'incrementalRefreshProperties', 'type': '[IncrementalRefreshProperties]'},
        'model_json_path': {'key': 'modelJsonPath', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, kind=None, is_active: bool=None, entity_names=None, entities_count: int=None, data_source_id: str=None, name: str=None, friendly_name: str=None, entity_information=None, provisioning_state=None, last_refresh=None, refresh_state=None, incremental_refresh_properties=None, model_json_path: str=None, version: int=None, updated_by: str=None, updated_utc=None, created_by: str=None, created_utc=None, instance_id: str=None, **kwargs) -> None:
        super(DataSourceMetadata, self).__init__(**kwargs)
        self.kind = kind
        self.is_active = is_active
        self.entity_names = entity_names
        self.entities_count = entities_count
        self.data_source_id = data_source_id
        self.name = name
        self.friendly_name = friendly_name
        self.entity_information = entity_information
        self.provisioning_state = provisioning_state
        self.last_refresh = last_refresh
        self.refresh_state = refresh_state
        self.incremental_refresh_properties = incremental_refresh_properties
        self.model_json_path = model_json_path
        self.version = version
        self.updated_by = updated_by
        self.updated_utc = updated_utc
        self.created_by = created_by
        self.created_utc = created_utc
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserInfo(Model):
    """Represents a User.

    :param user_id: Gets the unique ID for this user.
    :type user_id: str
    :param upn: Gets user identifier.
    :type upn: str
    :param instances_ids: Gets list of Instances Id.
    :type instances_ids:
     list[~dynamics.customerinsights.api.models.InstanceInfo]
    :param preferred_language: Gets user preferred language.
    :type preferred_language: str
    :param preferred_regional_format: Gets user preferred regional format.
    :type preferred_regional_format: str
    :param default_instance: Gets user default instance id.
    :type default_instance: str
    :param user_notifications_settings:
    :type user_notifications_settings:
     ~dynamics.customerinsights.api.models.UserNotificationsSettings
    :param industry_demo: Gets the industry demo selected by user during trial
    :type industry_demo: str
    :param tenant_id: Gets the tenant id of the user.
    :type tenant_id: str
    :param has_seen_welcome: Gets a value indicating whether the user has seen
     the all apps (welcome) page.
    :type has_seen_welcome: bool
    :param created_utc: Gets the created time of User settings created for EI
     Migration.
    :type created_utc: datetime
    :param allow_email_contacts: Gets a value indicating whether the user
     Opt-In to be contacted through emails. This is for CPM integration from
     EI.
    :type allow_email_contacts: bool
    :param portal_settings:
    :type portal_settings:
     ~dynamics.customerinsights.api.models.PortalSettings
    :param terms_of_use:
    :type terms_of_use: ~dynamics.customerinsights.api.models.TermsOfUse
    :param region: Gets the region that the user belongs to.
    :type region: str
    :param last_used_experience: Possible values include: 'audienceInsights',
     'engagementInsights', 'audienceInsightsB2B'
    :type last_used_experience: str or
     ~dynamics.customerinsights.api.models.enum
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'user_id': {'key': 'userId', 'type': 'str'},
        'upn': {'key': 'upn', 'type': 'str'},
        'instances_ids': {'key': 'instancesIds', 'type': '[InstanceInfo]'},
        'preferred_language': {'key': 'preferredLanguage', 'type': 'str'},
        'preferred_regional_format': {'key': 'preferredRegionalFormat', 'type': 'str'},
        'default_instance': {'key': 'defaultInstance', 'type': 'str'},
        'user_notifications_settings': {'key': 'userNotificationsSettings', 'type': 'UserNotificationsSettings'},
        'industry_demo': {'key': 'industryDemo', 'type': 'str'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
        'has_seen_welcome': {'key': 'hasSeenWelcome', 'type': 'bool'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'allow_email_contacts': {'key': 'allowEmailContacts', 'type': 'bool'},
        'portal_settings': {'key': 'portalSettings', 'type': 'PortalSettings'},
        'terms_of_use': {'key': 'termsOfUse', 'type': 'TermsOfUse'},
        'region': {'key': 'region', 'type': 'str'},
        'last_used_experience': {'key': 'lastUsedExperience', 'type': 'str'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, user_id: str=None, upn: str=None, instances_ids=None, preferred_language: str=None, preferred_regional_format: str=None, default_instance: str=None, user_notifications_settings=None, industry_demo: str=None, tenant_id: str=None, has_seen_welcome: bool=None, created_utc=None, allow_email_contacts: bool=None, portal_settings=None, terms_of_use=None, region: str=None, last_used_experience=None, instance_id: str=None, **kwargs) -> None:
        super(UserInfo, self).__init__(**kwargs)
        self.user_id = user_id
        self.upn = upn
        self.instances_ids = instances_ids
        self.preferred_language = preferred_language
        self.preferred_regional_format = preferred_regional_format
        self.default_instance = default_instance
        self.user_notifications_settings = user_notifications_settings
        self.industry_demo = industry_demo
        self.tenant_id = tenant_id
        self.has_seen_welcome = has_seen_welcome
        self.created_utc = created_utc
        self.allow_email_contacts = allow_email_contacts
        self.portal_settings = portal_settings
        self.terms_of_use = terms_of_use
        self.region = region
        self.last_used_experience = last_used_experience
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureDimension(Model):
    """Represents a dimension.

    :param field: Gets the field on which group by will be applied
    :type field: str
    :param alias: Gets the alias for the field
    :type alias: str
    :param display_name: Gets the display name for the dimension
    :type display_name: str
    :param order: Gets the order for the dimension
    :type order: int
    :param bucket: Possible values include: 'none', 'day', 'month', 'year'
    :type bucket: str or ~dynamics.customerinsights.api.models.enum
    :param is_read_only: Gets a value indicating whether the dimension is
     readonly or not
    :type is_read_only: bool
    """

    _attribute_map = {
        'field': {'key': 'field', 'type': 'str'},
        'alias': {'key': 'alias', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'order': {'key': 'order', 'type': 'int'},
        'bucket': {'key': 'bucket', 'type': 'str'},
        'is_read_only': {'key': 'isReadOnly', 'type': 'bool'},
    }

    def __init__(self, *, field: str=None, alias: str=None, display_name: str=None, order: int=None, bucket=None, is_read_only: bool=None, **kwargs) -> None:
        super(MeasureDimension, self).__init__(**kwargs)
        self.field = field
        self.alias = alias
        self.display_name = display_name
        self.order = order
        self.bucket = bucket
        self.is_read_only = is_read_only



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IncrementalRefreshProperties(Model):
    """Represents a Incremental Refresh Property.

    :param entity_name: Name of the entity.
    :type entity_name: str
    :param detect_changes_attribute_name: Column to detect changes.
    :type detect_changes_attribute_name: str
    :param filter_by_attribute_name: Column to get incremental data.
    :type filter_by_attribute_name: str
    :param incremental_granularity: Granularity of the incremental refresh.
    :type incremental_granularity: str
    :param incremental_periods: Incremental period.
    :type incremental_periods: int
    :param refresh_complete_periods: Indicating whether to refresh completed
     periods or not.
    :type refresh_complete_periods: bool
    :param incremental_periods_offset: Off set period.
    :type incremental_periods_offset: int
    :param primary_key_attribute_name: Primary key of the entity.
    :type primary_key_attribute_name: str
    :param rolling_window_granularity: Rolling window granularity.
    :type rolling_window_granularity: str
    :param rolling_window_periods: Rolling window period.
    :type rolling_window_periods: int
    """

    _attribute_map = {
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'detect_changes_attribute_name': {'key': 'detectChangesAttributeName', 'type': 'str'},
        'filter_by_attribute_name': {'key': 'filterByAttributeName', 'type': 'str'},
        'incremental_granularity': {'key': 'incrementalGranularity', 'type': 'str'},
        'incremental_periods': {'key': 'incrementalPeriods', 'type': 'int'},
        'refresh_complete_periods': {'key': 'refreshCompletePeriods', 'type': 'bool'},
        'incremental_periods_offset': {'key': 'incrementalPeriodsOffset', 'type': 'int'},
        'primary_key_attribute_name': {'key': 'primaryKeyAttributeName', 'type': 'str'},
        'rolling_window_granularity': {'key': 'rollingWindowGranularity', 'type': 'str'},
        'rolling_window_periods': {'key': 'rollingWindowPeriods', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(IncrementalRefreshProperties, self).__init__(**kwargs)
        self.entity_name = kwargs.get('entity_name', None)
        self.detect_changes_attribute_name = kwargs.get('detect_changes_attribute_name', None)
        self.filter_by_attribute_name = kwargs.get('filter_by_attribute_name', None)
        self.incremental_granularity = kwargs.get('incremental_granularity', None)
        self.incremental_periods = kwargs.get('incremental_periods', None)
        self.refresh_complete_periods = kwargs.get('refresh_complete_periods', None)
        self.incremental_periods_offset = kwargs.get('incremental_periods_offset', None)
        self.primary_key_attribute_name = kwargs.get('primary_key_attribute_name', None)
        self.rolling_window_granularity = kwargs.get('rolling_window_granularity', None)
        self.rolling_window_periods = kwargs.get('rolling_window_periods', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityDependency(Model):
    """Represents a reference to an entity.

    :param qualified_entity_name: Gets the qualified entity name.
    :type qualified_entity_name: str
    :param type: Possible values include: 'unspecified', 'profile',
     'conflationMap', 'activity', 'aggregateKpi', 'profileKpi',
     'unifiedActivity', 'segment', 'intelligence', 'genericPrediction',
     'enrichment', 'insights', 'derivedEntity', 'corrupt', 'selfConflation',
     'conflationManualReview', 'selfConflationManualReview',
     'semanticActivity', 'segmentMembership', 'hierarchy', 'dataLineage',
     'transform', 'semanticEntity'
    :type type: str or ~dynamics.customerinsights.api.models.enum
    :param attribute_names: Gets the list of attributes included in the
     dependency.
    :type attribute_names: list[str]
    :param relationship_names: Gets the list of relationships included in the
     dependency
    :type relationship_names: list[str]
    :param activity_details: Contains the Activity type and entity name
     corresponding to that activity type.
    :type activity_details:
     list[~dynamics.customerinsights.api.models.InsightActivityDetails]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'attribute_names': {'key': 'attributeNames', 'type': '[str]'},
        'relationship_names': {'key': 'relationshipNames', 'type': '[str]'},
        'activity_details': {'key': 'activityDetails', 'type': '[InsightActivityDetails]'},
    }

    def __init__(self, *, qualified_entity_name: str=None, type=None, attribute_names=None, relationship_names=None, activity_details=None, **kwargs) -> None:
        super(EntityDependency, self).__init__(**kwargs)
        self.qualified_entity_name = qualified_entity_name
        self.type = type
        self.attribute_names = attribute_names
        self.relationship_names = relationship_names
        self.activity_details = activity_details



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataEntityPayload(Model):
    """ODataEntityPayload.

    :param odatacontext:
    :type odatacontext: str
    :param odatacount:
    :type odatacount: int
    :param value:
    :type value: list[object]
    """

    _attribute_map = {
        'odatacontext': {'key': '@odata\\.context', 'type': 'str'},
        'odatacount': {'key': '@odata\\.count', 'type': 'int'},
        'value': {'key': 'value', 'type': '[object]'},
    }

    def __init__(self, **kwargs):
        super(ODataEntityPayload, self).__init__(**kwargs)
        self.odatacontext = kwargs.get('odatacontext', None)
        self.odatacount = kwargs.get('odatacount', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentationPublishStats(Model):
    """SegmentationPublishStats.

    :param job_status: Possible values include: 'None', 'Queued', 'Running',
     'CompletedSuccess', 'CompletedFailure', 'Cancelled', 'Interrupted',
     'NotQualified'
    :type job_status: str or ~dynamics.customerinsights.api.models.enum
    :param evaluation_date:
    :type evaluation_date: datetime
    :param entity_count:
    :type entity_count: long
    :param error:
    :type error: ~dynamics.customerinsights.api.models.StringInfo
    :param last_successful_run_id:
    :type last_successful_run_id: str
    """

    _attribute_map = {
        'job_status': {'key': 'jobStatus', 'type': 'str'},
        'evaluation_date': {'key': 'evaluationDate', 'type': 'iso-8601'},
        'entity_count': {'key': 'entityCount', 'type': 'long'},
        'error': {'key': 'error', 'type': 'StringInfo'},
        'last_successful_run_id': {'key': 'lastSuccessfulRunId', 'type': 'str'},
    }

    def __init__(self, *, job_status=None, evaluation_date=None, entity_count: int=None, error=None, last_successful_run_id: str=None, **kwargs) -> None:
        super(SegmentationPublishStats, self).__init__(**kwargs)
        self.job_status = job_status
        self.evaluation_date = evaluation_date
        self.entity_count = entity_count
        self.error = error
        self.last_successful_run_id = last_successful_run_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceProvisioningError(Model):
    """Represents an instance provisioning error.

    :param error_code: Possible values include:
     'invalidDynamics365DataSourceCredentials',
     'invalidSalesforceDataSourceCredentials', 'internalError',
     'bapCannotCreateEnvironment'
    :type error_code: str or ~dynamics.customerinsights.api.models.enum
    :param error_args: Gets string formatting arguments for the provisioning
     error
    :type error_args: list[str]
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'error_args': {'key': 'errorArgs', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(InstanceProvisioningError, self).__init__(**kwargs)
        self.error_code = kwargs.get('error_code', None)
        self.error_args = kwargs.get('error_args', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WorkflowRefreshSchedule(Model):
    """Represents a DAG refresh schedule.

    :param operation_type: Possible values include: 'none', 'ingestion',
     'derivedEntity', 'hierarchy', 'dataPreparation', 'map',
     'realtimeM3Search', 'match', 'merge', 'profileStore', 'search',
     'activity', 'contact', 'attributeMeasures', 'entityMeasures', 'measures',
     'segmentation', 'segmentMembership', 'enrichment', 'preEnrichment',
     'transform', 'intelligence', 'aiBuilder', 'insights', 'export',
     'modelManagement', 'relationship', 'roleAssignment', 'analysis',
     'semanticEntity', 'all'
    :type operation_type: str or ~dynamics.customerinsights.api.models.enum
    :param sub_type: Possible values include: 'noSubType',
     'templatedMeasures', 'createAnalysisModel', 'linkAnalysisModel',
     'singleActivityMapping', 'powerPlatform'
    :type sub_type: str or ~dynamics.customerinsights.api.models.enum
    :param identifiers: Gets the identifiers of the schedule
    :type identifiers: list[str]
    :param job_type: Possible values include: 'full', 'incremental'
    :type job_type: str or ~dynamics.customerinsights.api.models.enum
    :param is_active: Gets a value indicating whether the schedule is active.
    :type is_active: bool
    :param timezone_id: Gets the ID of the timezone
    :type timezone_id: str
    :param cron_schedules: Gets the schedule in CRON format
    :type cron_schedules: list[str]
    :param schedule_id: Gets the ID of the schedule
    :type schedule_id: str
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'operation_type': {'key': 'operationType', 'type': 'str'},
        'sub_type': {'key': 'subType', 'type': 'str'},
        'identifiers': {'key': 'identifiers', 'type': '[str]'},
        'job_type': {'key': 'jobType', 'type': 'str'},
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'timezone_id': {'key': 'timezoneId', 'type': 'str'},
        'cron_schedules': {'key': 'cronSchedules', 'type': '[str]'},
        'schedule_id': {'key': 'scheduleId', 'type': 'str'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, operation_type=None, sub_type=None, identifiers=None, job_type=None, is_active: bool=None, timezone_id: str=None, cron_schedules=None, schedule_id: str=None, instance_id: str=None, **kwargs) -> None:
        super(WorkflowRefreshSchedule, self).__init__(**kwargs)
        self.operation_type = operation_type
        self.sub_type = sub_type
        self.identifiers = identifiers
        self.job_type = job_type
        self.is_active = is_active
        self.timezone_id = timezone_id
        self.cron_schedules = cron_schedules
        self.schedule_id = schedule_id
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CdsOrgInfo(Model):
    """The information for CDS Organization in BAP.

    :param friendly_name: Gets the Cds Organization Friendly Name
    :type friendly_name: str
    :param url: Gets the Cds Organization Url
    :type url: str
    :param state: Gets the Cds Organization State
    :type state: str
    :param location: Gets region location of Cds Organization
    :type location: str
    :param environment_sku: Gets SKU of Cds Organization
    :type environment_sku: str
    :param expiration_time: Gets the expiration time of CDS Organization if
     the SKU is Trial
    :type expiration_time: datetime
    :param max_allowed_expiration_time: Gets the max allowed expiration time
     of CDS Organization if the SKU is Trial
    :type max_allowed_expiration_time: datetime
    """

    _attribute_map = {
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'environment_sku': {'key': 'environmentSku', 'type': 'str'},
        'expiration_time': {'key': 'expirationTime', 'type': 'iso-8601'},
        'max_allowed_expiration_time': {'key': 'maxAllowedExpirationTime', 'type': 'iso-8601'},
    }

    def __init__(self, *, friendly_name: str=None, url: str=None, state: str=None, location: str=None, environment_sku: str=None, expiration_time=None, max_allowed_expiration_time=None, **kwargs) -> None:
        super(CdsOrgInfo, self).__init__(**kwargs)
        self.friendly_name = friendly_name
        self.url = url
        self.state = state
        self.location = location
        self.environment_sku = environment_sku
        self.expiration_time = expiration_time
        self.max_allowed_expiration_time = max_allowed_expiration_time



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SelectionReason(Model):
    """SelectionReason.

    :param code: Possible values include: 'unknown', 'requested', 'firstRun',
     'unsuccessful', 'lastRunSkipped', 'alreadyRunning', 'modifiedInputs',
     'upstreamRerunning', 'dependantSystemNode', 'dependsOnMerge'
    :type code: str or ~dynamics.customerinsights.api.models.enum
    :param details:
    :type details: str
    """

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'details': {'key': 'details', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SelectionReason, self).__init__(**kwargs)
        self.code = kwargs.get('code', None)
        self.details = kwargs.get('details', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class History(Model):
    """Defaults or user selected values to store across sessions.

    :param id: Gets history id.
    :type id: str
    :param viewed: Checks for already visited.
    :type viewed: bool
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'viewed': {'key': 'viewed', 'type': 'bool'},
    }

    def __init__(self, *, id: str=None, viewed: bool=None, **kwargs) -> None:
        super(History, self).__init__(**kwargs)
        self.id = id
        self.viewed = viewed



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReferenceModel(Model):
    """ReferenceModel.

    :param id:
    :type id: str
    :param location:
    :type location: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, location: str=None, **kwargs) -> None:
        super(ReferenceModel, self).__init__(**kwargs)
        self.id = id
        self.location = location



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentationProjection(Model):
    """Represent a Segment Projection.

    :param entity_name: Gets the Entity Name of the projection.
    :type entity_name: str
    :param attribute_names: Gets the Attribute Names being projected.
    :type attribute_names: list[str]
    :param path: Gets the relationship path to use for segment projection.
    :type path: list[str]
    :param projection_type: Possible values include: 'pre', 'post'
    :type projection_type: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'attribute_names': {'key': 'attributeNames', 'type': '[str]'},
        'path': {'key': 'path', 'type': '[str]'},
        'projection_type': {'key': 'projectionType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SegmentationProjection, self).__init__(**kwargs)
        self.entity_name = kwargs.get('entity_name', None)
        self.attribute_names = kwargs.get('attribute_names', None)
        self.path = kwargs.get('path', None)
        self.projection_type = kwargs.get('projection_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Model(Model):
    """Model.

    :param name:
    :type name: str
    :param description:
    :type description: str
    :param is_hidden:
    :type is_hidden: bool
    :param version:
    :type version: str
    :param culture:
    :type culture: str
    :param pbitime_zone:
    :type pbitime_zone: str
    :param modified_time:
    :type modified_time: datetime
    :param pbimashup:
    :type pbimashup: ~dynamics.customerinsights.api.models.Mashup
    :param annotations:
    :type annotations: list[~dynamics.customerinsights.api.models.Annotation]
    :param entities:
    :type entities: list[~dynamics.customerinsights.api.models.Entity]
    :param relationships:
    :type relationships:
     list[~dynamics.customerinsights.api.models.Relationship]
    :param reference_models:
    :type reference_models:
     list[~dynamics.customerinsights.api.models.ReferenceModel]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'is_hidden': {'key': 'isHidden', 'type': 'bool'},
        'version': {'key': 'version', 'type': 'str'},
        'culture': {'key': 'culture', 'type': 'str'},
        'pbitime_zone': {'key': 'pbi:timeZone', 'type': 'str'},
        'modified_time': {'key': 'modifiedTime', 'type': 'iso-8601'},
        'pbimashup': {'key': 'pbi:mashup', 'type': 'Mashup'},
        'annotations': {'key': 'annotations', 'type': '[Annotation]'},
        'entities': {'key': 'entities', 'type': '[Entity]'},
        'relationships': {'key': 'relationships', 'type': '[Relationship]'},
        'reference_models': {'key': 'referenceModels', 'type': '[ReferenceModel]'},
    }

    def __init__(self, **kwargs):
        super(Model, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.is_hidden = kwargs.get('is_hidden', None)
        self.version = kwargs.get('version', None)
        self.culture = kwargs.get('culture', None)
        self.pbitime_zone = kwargs.get('pbitime_zone', None)
        self.modified_time = kwargs.get('modified_time', None)
        self.pbimashup = kwargs.get('pbimashup', None)
        self.annotations = kwargs.get('annotations', None)
        self.entities = kwargs.get('entities', None)
        self.relationships = kwargs.get('relationships', None)
        self.reference_models = kwargs.get('reference_models', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyDefinition(Model):
    """Represents a Hierarchy entity used to define a B2B segment/measure.

    :param hierarchy_entity_name: Gets the Hierarchy entity fully qualified
     name.
    :type hierarchy_entity_name: str
    :param source_attribute_name: Gets the Hierarchy entity Source attribute
     name.
    :type source_attribute_name: str
    :param destination_attribute_name: Gets the Hierarchy entity Destination
     attribute name.
    :type destination_attribute_name: str
    """

    _attribute_map = {
        'hierarchy_entity_name': {'key': 'hierarchyEntityName', 'type': 'str'},
        'source_attribute_name': {'key': 'sourceAttributeName', 'type': 'str'},
        'destination_attribute_name': {'key': 'destinationAttributeName', 'type': 'str'},
    }

    def __init__(self, *, hierarchy_entity_name: str=None, source_attribute_name: str=None, destination_attribute_name: str=None, **kwargs) -> None:
        super(HierarchyDefinition, self).__init__(**kwargs)
        self.hierarchy_entity_name = hierarchy_entity_name
        self.source_attribute_name = source_attribute_name
        self.destination_attribute_name = destination_attribute_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SqlValidationStats(Model):
    """Represents measure sql validation stats.

    :param validation_date: Date of Validation evaluation
    :type validation_date: datetime
    :param error: Gets the number of consecutive failures
    :type error: str
    """

    _attribute_map = {
        'validation_date': {'key': 'validationDate', 'type': 'iso-8601'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, *, validation_date=None, error: str=None, **kwargs) -> None:
        super(SqlValidationStats, self).__init__(**kwargs)
        self.validation_date = validation_date
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Mashup(Model):
    """Mashup.

    :param fast_combine:
    :type fast_combine: bool
    :param allow_native_queries:
    :type allow_native_queries: bool
    :param queries_metadata:
    :type queries_metadata: dict[str,
     ~dynamics.customerinsights.api.models.QueryMetadata]
    :param document:
    :type document: str
    """

    _attribute_map = {
        'fast_combine': {'key': 'fastCombine', 'type': 'bool'},
        'allow_native_queries': {'key': 'allowNativeQueries', 'type': 'bool'},
        'queries_metadata': {'key': 'queriesMetadata', 'type': '{QueryMetadata}'},
        'document': {'key': 'document', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(Mashup, self).__init__(**kwargs)
        self.fast_combine = kwargs.get('fast_combine', None)
        self.allow_native_queries = kwargs.get('allow_native_queries', None)
        self.queries_metadata = kwargs.get('queries_metadata', None)
        self.document = kwargs.get('document', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceCopyRequest(Model):
    """InstanceCopyRequest.

    :param instance_id_to_copy:
    :type instance_id_to_copy: str
    :param instance_metadata:
    :type instance_metadata:
     ~dynamics.customerinsights.api.models.InstanceMetadata
    :param byosa_resource_metadata:
    :type byosa_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param cds_resource_metadata:
    :type cds_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param is_cds_mdl_storage_enabled:
    :type is_cds_mdl_storage_enabled: bool
    :param is_ci_to_byosa_migration_enabled:
    :type is_ci_to_byosa_migration_enabled: bool
    :param bap_provisioning_type: Possible values include: 'skip', 'create',
     'attach'
    :type bap_provisioning_type: str or
     ~dynamics.customerinsights.api.models.enum
    :param is_pbi_provisioning_required:
    :type is_pbi_provisioning_required: bool
    :param is_dataverse_update_requested:
    :type is_dataverse_update_requested: bool
    """

    _attribute_map = {
        'instance_id_to_copy': {'key': 'instanceIdToCopy', 'type': 'str'},
        'instance_metadata': {'key': 'instanceMetadata', 'type': 'InstanceMetadata'},
        'byosa_resource_metadata': {'key': 'byosaResourceMetadata', 'type': 'ResourceMetadata'},
        'cds_resource_metadata': {'key': 'cdsResourceMetadata', 'type': 'ResourceMetadata'},
        'is_cds_mdl_storage_enabled': {'key': 'isCdsMdlStorageEnabled', 'type': 'bool'},
        'is_ci_to_byosa_migration_enabled': {'key': 'isCiToByosaMigrationEnabled', 'type': 'bool'},
        'bap_provisioning_type': {'key': 'bapProvisioningType', 'type': 'str'},
        'is_pbi_provisioning_required': {'key': 'isPbiProvisioningRequired', 'type': 'bool'},
        'is_dataverse_update_requested': {'key': 'isDataverseUpdateRequested', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(InstanceCopyRequest, self).__init__(**kwargs)
        self.instance_id_to_copy = kwargs.get('instance_id_to_copy', None)
        self.instance_metadata = kwargs.get('instance_metadata', None)
        self.byosa_resource_metadata = kwargs.get('byosa_resource_metadata', None)
        self.cds_resource_metadata = kwargs.get('cds_resource_metadata', None)
        self.is_cds_mdl_storage_enabled = kwargs.get('is_cds_mdl_storage_enabled', None)
        self.is_ci_to_byosa_migration_enabled = kwargs.get('is_ci_to_byosa_migration_enabled', None)
        self.bap_provisioning_type = kwargs.get('bap_provisioning_type', None)
        self.is_pbi_provisioning_required = kwargs.get('is_pbi_provisioning_required', None)
        self.is_dataverse_update_requested = kwargs.get('is_dataverse_update_requested', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Notifications(Model):
    """Settings to track notifications that users have viewed and dismissed.

    :param history:
    :type history: ~dynamics.customerinsights.api.models.History
    """

    _attribute_map = {
        'history': {'key': 'history', 'type': 'History'},
    }

    def __init__(self, **kwargs):
        super(Notifications, self).__init__(**kwargs)
        self.history = kwargs.get('history', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivitySourceEntityInfo(Model):
    """Collection of the entity name and other info of the source activity entity
    ingested by user.

    :param entity_name: Gets the qualified entity name of the activity source
     entity.
    :type entity_name: str
    """

    _attribute_map = {
        'entity_name': {'key': 'entityName', 'type': 'str'},
    }

    def __init__(self, *, entity_name: str=None, **kwargs) -> None:
        super(ActivitySourceEntityInfo, self).__init__(**kwargs)
        self.entity_name = entity_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GraphJobInfo(Model):
    """GraphJobInfo.

    :param job_id:
    :type job_id: str
    :param job_type: Possible values include: 'full', 'incremental'
    :type job_type: str or ~dynamics.customerinsights.api.models.enum
    :param job_submission_kind: Possible values include: 'onDemand',
     'scheduled'
    :type job_submission_kind: str or
     ~dynamics.customerinsights.api.models.enum
    :param job_status: Possible values include: 'queued', 'needsUpdate',
     'running', 'failed', 'timedOut', 'aborted', 'deleted', 'successful',
     'skipped'
    :type job_status: str or ~dynamics.customerinsights.api.models.enum
    :param operation_type: Possible values include: 'none', 'ingestion',
     'derivedEntity', 'hierarchy', 'dataPreparation', 'map',
     'realtimeM3Search', 'match', 'merge', 'profileStore', 'search',
     'activity', 'contact', 'attributeMeasures', 'entityMeasures', 'measures',
     'segmentation', 'segmentMembership', 'enrichment', 'preEnrichment',
     'transform', 'intelligence', 'aiBuilder', 'insights', 'export',
     'modelManagement', 'relationship', 'roleAssignment', 'analysis',
     'semanticEntity', 'all'
    :type operation_type: str or ~dynamics.customerinsights.api.models.enum
    :param sub_type: Possible values include: 'noSubType',
     'templatedMeasures', 'createAnalysisModel', 'linkAnalysisModel',
     'singleActivityMapping', 'powerPlatform'
    :type sub_type: str or ~dynamics.customerinsights.api.models.enum
    :param end_timestamp:
    :type end_timestamp: datetime
    :param should_force_run_requested_nodes:
    :type should_force_run_requested_nodes: bool
    :param tasks:
    :type tasks: list[~dynamics.customerinsights.api.models.GraphTaskInfo]
    :param id_list:
    :type id_list: list[str]
    :param options:
    :type options: ~dynamics.customerinsights.api.models.GraphJobOptions
    :param submitted_timestamp:
    :type submitted_timestamp: datetime
    """

    _attribute_map = {
        'job_id': {'key': 'jobId', 'type': 'str'},
        'job_type': {'key': 'jobType', 'type': 'str'},
        'job_submission_kind': {'key': 'jobSubmissionKind', 'type': 'str'},
        'job_status': {'key': 'jobStatus', 'type': 'str'},
        'operation_type': {'key': 'operationType', 'type': 'str'},
        'sub_type': {'key': 'subType', 'type': 'str'},
        'end_timestamp': {'key': 'endTimestamp', 'type': 'iso-8601'},
        'should_force_run_requested_nodes': {'key': 'shouldForceRunRequestedNodes', 'type': 'bool'},
        'tasks': {'key': 'tasks', 'type': '[GraphTaskInfo]'},
        'id_list': {'key': 'idList', 'type': '[str]'},
        'options': {'key': 'options', 'type': 'GraphJobOptions'},
        'submitted_timestamp': {'key': 'submittedTimestamp', 'type': 'iso-8601'},
    }

    def __init__(self, *, job_id: str=None, job_type=None, job_submission_kind=None, job_status=None, operation_type=None, sub_type=None, end_timestamp=None, should_force_run_requested_nodes: bool=None, tasks=None, id_list=None, options=None, submitted_timestamp=None, **kwargs) -> None:
        super(GraphJobInfo, self).__init__(**kwargs)
        self.job_id = job_id
        self.job_type = job_type
        self.job_submission_kind = job_submission_kind
        self.job_status = job_status
        self.operation_type = operation_type
        self.sub_type = sub_type
        self.end_timestamp = end_timestamp
        self.should_force_run_requested_nodes = should_force_run_requested_nodes
        self.tasks = tasks
        self.id_list = id_list
        self.options = options
        self.submitted_timestamp = submitted_timestamp



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttributeSearchProperties(Model):
    """Represents search configuration for an attribute.

    :param is_searchable: Gets a value indicating whether the attribute
     supports full text search.
    :type is_searchable: bool
    :param is_filterable: Gets a value indicating whether the attribute
     supports filtering.
    :type is_filterable: bool
    :param is_facetable: Gets a value indicating whether the attribute can be
     included as facet results.
    :type is_facetable: bool
    :param facet_specification: Gets an optional specification for search
     faceting used at query time (advanced).
    :type facet_specification: str
    :param is_sortable: Gets a value indicating whether the attribute supports
     ordering.
    :type is_sortable: bool
    """

    _attribute_map = {
        'is_searchable': {'key': 'isSearchable', 'type': 'bool'},
        'is_filterable': {'key': 'isFilterable', 'type': 'bool'},
        'is_facetable': {'key': 'isFacetable', 'type': 'bool'},
        'facet_specification': {'key': 'facetSpecification', 'type': 'str'},
        'is_sortable': {'key': 'isSortable', 'type': 'bool'},
    }

    def __init__(self, *, is_searchable: bool=None, is_filterable: bool=None, is_facetable: bool=None, facet_specification: str=None, is_sortable: bool=None, **kwargs) -> None:
        super(AttributeSearchProperties, self).__init__(**kwargs)
        self.is_searchable = is_searchable
        self.is_filterable = is_filterable
        self.is_facetable = is_facetable
        self.facet_specification = facet_specification
        self.is_sortable = is_sortable



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureDefinition(Model):
    """Represents a measure definition.

    :param kind: Possible values include: 'entity', 'attribute'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param is_scalar: Gets a value indicating whether the current measure is a
     scalar measure e doesn't have any dimensions
    :type is_scalar: bool
    :param linked_entities: Gets list of linked entities associated with the
     measure.
    :type linked_entities:
     list[~dynamics.customerinsights.api.models.MeasureLinkedEntity]
    :param variables: Gets list of variables (computed columns) for the
     measure.
    :type variables:
     list[~dynamics.customerinsights.api.models.MeasureVariable]
    :param filters:
    :type filters: ~dynamics.customerinsights.api.models.MeasureExpression
    :param filtering_criteria:
    :type filtering_criteria:
     ~dynamics.customerinsights.api.models.SegmentMembershipCriteria
    :param dimensions: Gets list of dimensions with the measure.
    :type dimensions:
     list[~dynamics.customerinsights.api.models.MeasureDimension]
    :param aggregates: Gets list of aggregates of the measure.
    :type aggregates:
     list[~dynamics.customerinsights.api.models.MeasureAggregate]
    :param is_profile: Gets a value indicating whether the current measure is
     a profile measure
    :type is_profile: bool
    :param measure_query_sql: Gets the user specified custom SQL query.
    :type measure_query_sql: str
    :param type: Possible values include: 'structured', 'manual'
    :type type: str or ~dynamics.customerinsights.api.models.enum
    :param is_manual_query_scalar: Gets the indicating whether the Business
     Measure is Scalar or not.
    :type is_manual_query_scalar: bool
    :param dependencies: Gets the list of measures that this measure depends
     on.
    :type dependencies:
     list[~dynamics.customerinsights.api.models.EntityDependency]
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'is_scalar': {'key': 'isScalar', 'type': 'bool'},
        'linked_entities': {'key': 'linkedEntities', 'type': '[MeasureLinkedEntity]'},
        'variables': {'key': 'variables', 'type': '[MeasureVariable]'},
        'filters': {'key': 'filters', 'type': 'MeasureExpression'},
        'filtering_criteria': {'key': 'filteringCriteria', 'type': 'SegmentMembershipCriteria'},
        'dimensions': {'key': 'dimensions', 'type': '[MeasureDimension]'},
        'aggregates': {'key': 'aggregates', 'type': '[MeasureAggregate]'},
        'is_profile': {'key': 'isProfile', 'type': 'bool'},
        'measure_query_sql': {'key': 'measureQuerySql', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'is_manual_query_scalar': {'key': 'isManualQueryScalar', 'type': 'bool'},
        'dependencies': {'key': 'dependencies', 'type': '[EntityDependency]'},
    }

    def __init__(self, **kwargs):
        super(MeasureDefinition, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.is_scalar = kwargs.get('is_scalar', None)
        self.linked_entities = kwargs.get('linked_entities', None)
        self.variables = kwargs.get('variables', None)
        self.filters = kwargs.get('filters', None)
        self.filtering_criteria = kwargs.get('filtering_criteria', None)
        self.dimensions = kwargs.get('dimensions', None)
        self.aggregates = kwargs.get('aggregates', None)
        self.is_profile = kwargs.get('is_profile', None)
        self.measure_query_sql = kwargs.get('measure_query_sql', None)
        self.type = kwargs.get('type', None)
        self.is_manual_query_scalar = kwargs.get('is_manual_query_scalar', None)
        self.dependencies = kwargs.get('dependencies', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class KeyRingResponse(Model):
    """KeyRingResponse.

    :param instance_id:
    :type instance_id: str
    :param customer_id:
    :type customer_id: str
    :param key_ring:
    :type key_ring: object
    """

    _attribute_map = {
        'instance_id': {'key': 'instanceId', 'type': 'str'},
        'customer_id': {'key': 'customerId', 'type': 'str'},
        'key_ring': {'key': 'keyRing', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(KeyRingResponse, self).__init__(**kwargs)
        self.instance_id = kwargs.get('instance_id', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.key_ring = kwargs.get('key_ring', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TermsOfUse(Model):
    """Represents a Terms of Use for user.

    :param state: Possible values include: 'none', 'accepted', 'declined'
    :type state: str or ~dynamics.customerinsights.api.models.enum
    :param version: Gets the current version of this document.
    :type version: str
    :param created_utc: Gets the created time of terms acceptance.
    :type created_utc: datetime
    """

    _attribute_map = {
        'state': {'key': 'state', 'type': 'str'},
        'version': {'key': 'version', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(TermsOfUse, self).__init__(**kwargs)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        self.created_utc = kwargs.get('created_utc', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntitySearchConfiguration(Model):
    """EntitySearchConfiguration.

    :param qualified_entity_name: Gets unique entity name for this entity
    :type qualified_entity_name: str
    :param attributes: Gets the attribute search config
    :type attributes:
     list[~dynamics.customerinsights.api.models.AttributeSearchConfiguration]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'attributes': {'key': 'attributes', 'type': '[AttributeSearchConfiguration]'},
    }

    def __init__(self, *, qualified_entity_name: str=None, attributes=None, **kwargs) -> None:
        super(EntitySearchConfiguration, self).__init__(**kwargs)
        self.qualified_entity_name = qualified_entity_name
        self.attributes = attributes



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ByoPbiProvisioningInfo(Model):
    """The information for bring your own Power BI.

    :param storage_subscription_id: Storage account subscriptionId.
    :type storage_subscription_id: str
    :param storage_resource_group: Storage account Resource Group.
    :type storage_resource_group: str
    :param storage_resource_region: Storage account Region.
    :type storage_resource_region: str
    :param storage_resource_tenant_id: Storage account tenant.
    :type storage_resource_tenant_id: str
    :param capacity_id: Pbi Capacity Id.
    :type capacity_id: str
    :param synapse_serverless_sql_host_name: Synapse serverless sql host name
    :type synapse_serverless_sql_host_name: str
    """

    _attribute_map = {
        'storage_subscription_id': {'key': 'storageSubscriptionId', 'type': 'str'},
        'storage_resource_group': {'key': 'storageResourceGroup', 'type': 'str'},
        'storage_resource_region': {'key': 'storageResourceRegion', 'type': 'str'},
        'storage_resource_tenant_id': {'key': 'storageResourceTenantId', 'type': 'str'},
        'capacity_id': {'key': 'capacityId', 'type': 'str'},
        'synapse_serverless_sql_host_name': {'key': 'synapseServerlessSqlHostName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ByoPbiProvisioningInfo, self).__init__(**kwargs)
        self.storage_subscription_id = kwargs.get('storage_subscription_id', None)
        self.storage_resource_group = kwargs.get('storage_resource_group', None)
        self.storage_resource_region = kwargs.get('storage_resource_region', None)
        self.storage_resource_tenant_id = kwargs.get('storage_resource_tenant_id', None)
        self.capacity_id = kwargs.get('capacity_id', None)
        self.synapse_serverless_sql_host_name = kwargs.get('synapse_serverless_sql_host_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserNotificationsSettings(Model):
    """Represents a user notifications settings.

    :param dismissed_banner_notifications: Gets the list of dismissed banner
     notifications for this user.
    :type dismissed_banner_notifications:
     list[~dynamics.customerinsights.api.models.DismissedNotification]
    """

    _attribute_map = {
        'dismissed_banner_notifications': {'key': 'dismissedBannerNotifications', 'type': '[DismissedNotification]'},
    }

    def __init__(self, *, dismissed_banner_notifications=None, **kwargs) -> None:
        super(UserNotificationsSettings, self).__init__(**kwargs)
        self.dismissed_banner_notifications = dismissed_banner_notifications



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrialExtensionDetails(Model):
    """Extension Details of trial instance.

    :param extended_on: Gets the extended on date
    :type extended_on: datetime
    :param extended_for_days: Gets the number of days Extended
    :type extended_for_days: str
    :param extended_by: Gets the Name of Extended By
    :type extended_by: str
    """

    _attribute_map = {
        'extended_on': {'key': 'extendedOn', 'type': 'iso-8601'},
        'extended_for_days': {'key': 'extendedForDays', 'type': 'str'},
        'extended_by': {'key': 'extendedBy', 'type': 'str'},
    }

    def __init__(self, *, extended_on=None, extended_for_days: str=None, extended_by: str=None, **kwargs) -> None:
        super(TrialExtensionDetails, self).__init__(**kwargs)
        self.extended_on = extended_on
        self.extended_for_days = extended_for_days
        self.extended_by = extended_by



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HistogramBin(Model):
    """Histogram bin.

    :param lower_bound: Lower bound of Histogram bin.
    :type lower_bound: float
    :param upper_bound: Upper bound Histogram bin.
    :type upper_bound: float
    :param count: Represents an approximation count of the bin count.
    :type count: float
    """

    _attribute_map = {
        'lower_bound': {'key': 'lowerBound', 'type': 'float'},
        'upper_bound': {'key': 'upperBound', 'type': 'float'},
        'count': {'key': 'count', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(HistogramBin, self).__init__(**kwargs)
        self.lower_bound = kwargs.get('lower_bound', None)
        self.upper_bound = kwargs.get('upper_bound', None)
        self.count = kwargs.get('count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MappedSecretMetadata(Model):
    """Represents mapping between enity fields and Linked Metadata.

    :param mapped_field_id: The identifier for field mapping to a keyVault
    :type mapped_field_id: str
    :param linked_key_vault_metadata_id: Gets uniqueId of the KeyVault
    :type linked_key_vault_metadata_id: str
    :param mapping_entity_id: Gets uniqueId of entity Mapping Secrets
    :type mapping_entity_id: str
    :param byo_key_vault_field_mapping: Gets Secret Names for Fields Mapped in
     KeyVault
    :type byo_key_vault_field_mapping: dict[str, str]
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'mapped_field_id': {'key': 'mappedFieldId', 'type': 'str'},
        'linked_key_vault_metadata_id': {'key': 'linkedKeyVaultMetadataId', 'type': 'str'},
        'mapping_entity_id': {'key': 'mappingEntityId', 'type': 'str'},
        'byo_key_vault_field_mapping': {'key': 'byoKeyVaultFieldMapping', 'type': '{str}'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MappedSecretMetadata, self).__init__(**kwargs)
        self.mapped_field_id = kwargs.get('mapped_field_id', None)
        self.linked_key_vault_metadata_id = kwargs.get('linked_key_vault_metadata_id', None)
        self.mapping_entity_id = kwargs.get('mapping_entity_id', None)
        self.byo_key_vault_field_mapping = kwargs.get('byo_key_vault_field_mapping', None)
        self.instance_id = kwargs.get('instance_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntitySize(Model):
    """The information about an entity size.

    :param qualified_entity_name: Gets the entity Name
    :type qualified_entity_name: str
    :param size: Gets the size of the entire entity (in Bytes)
    :type size: long
    :param row_count: Gets the row count of the entity
    :type row_count: long
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'size': {'key': 'size', 'type': 'long'},
        'row_count': {'key': 'rowCount', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(EntitySize, self).__init__(**kwargs)
        self.qualified_entity_name = kwargs.get('qualified_entity_name', None)
        self.size = kwargs.get('size', None)
        self.row_count = kwargs.get('row_count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SourceLocation(Model):
    """SourceLocation.

    :param line:
    :type line: int
    :param column:
    :type column: int
    """

    _attribute_map = {
        'line': {'key': 'line', 'type': 'int'},
        'column': {'key': 'column', 'type': 'int'},
    }

    def __init__(self, *, line: int=None, column: int=None, **kwargs) -> None:
        super(SourceLocation, self).__init__(**kwargs)
        self.line = line
        self.column = column



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HistoricalSegmentStats(Model):
    """Represents historical Segment statistics.

    :param evaluation_date: Gets the segment ran date.
    :type evaluation_date: datetime
    :param entity_count: Gets the count of entity.
    :type entity_count: long
    :param job_status: Gets the segment evaluation job status.
    :type job_status: str
    :param error:
    :type error: ~dynamics.customerinsights.api.models.StringInfo
    """

    _attribute_map = {
        'evaluation_date': {'key': 'evaluationDate', 'type': 'iso-8601'},
        'entity_count': {'key': 'entityCount', 'type': 'long'},
        'job_status': {'key': 'jobStatus', 'type': 'str'},
        'error': {'key': 'error', 'type': 'StringInfo'},
    }

    def __init__(self, *, evaluation_date=None, entity_count: int=None, job_status: str=None, error=None, **kwargs) -> None:
        super(HistoricalSegmentStats, self).__init__(**kwargs)
        self.evaluation_date = evaluation_date
        self.entity_count = entity_count
        self.job_status = job_status
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataSourceInfo(Model):
    """Data source Information.

    :param data_source_metadata:
    :type data_source_metadata:
     ~dynamics.customerinsights.api.models.DataSourceMetadata
    :param model:
    :type model: ~dynamics.customerinsights.api.models.Model
    """

    _attribute_map = {
        'data_source_metadata': {'key': 'dataSourceMetadata', 'type': 'DataSourceMetadata'},
        'model': {'key': 'model', 'type': 'Model'},
    }

    def __init__(self, *, data_source_metadata=None, model=None, **kwargs) -> None:
        super(DataSourceInfo, self).__init__(**kwargs)
        self.data_source_metadata = data_source_metadata
        self.model = model



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IEdmType(Model):
    """IEdmType.

    :param type_kind: Possible values include: 'none', 'primitive', 'entity',
     'complex', 'collection', 'entityReference', 'enum', 'typeDefinition',
     'untyped', 'path'
    :type type_kind: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'type_kind': {'key': 'typeKind', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IEdmType, self).__init__(**kwargs)
        self.type_kind = kwargs.get('type_kind', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmbeddedReport(Model):
    """Represents a embedded PowerBI report.

    :param report_type: Possible values include: 'overview', 'sales',
     'marketing', 'service', 'instanceZero'
    :type report_type: str or ~dynamics.customerinsights.api.models.enum
    :param embed_url: Gets the Uri used for Power BI report embedding.
    :type embed_url: str
    :param report_id: Gets the id used for Power BI report embedding.
    :type report_id: str
    """

    _attribute_map = {
        'report_type': {'key': 'reportType', 'type': 'str'},
        'embed_url': {'key': 'embedUrl', 'type': 'str'},
        'report_id': {'key': 'reportId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EmbeddedReport, self).__init__(**kwargs)
        self.report_type = kwargs.get('report_type', None)
        self.embed_url = kwargs.get('embed_url', None)
        self.report_id = kwargs.get('report_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureVariable(Model):
    """Represents a variable (computed column) in a measure.

    :param kind: Possible values include: 'arithmetic', 'date'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param name: Gets the name of the variable
    :type name: str
    :param data_type: Gets the data type of the variable
    :type data_type: str
    :param expression_text: Gets the expression text for computing the
     variable
    :type expression_text: str
    :param variable_condition_groups: Gets the variable conditions
    :type variable_condition_groups:
     list[~dynamics.customerinsights.api.models.MeasureVariableConditionGroup]
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'expression_text': {'key': 'expressionText', 'type': 'str'},
        'variable_condition_groups': {'key': 'variableConditionGroups', 'type': '[MeasureVariableConditionGroup]'},
    }

    def __init__(self, **kwargs):
        super(MeasureVariable, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.name = kwargs.get('name', None)
        self.data_type = kwargs.get('data_type', None)
        self.expression_text = kwargs.get('expression_text', None)
        self.variable_condition_groups = kwargs.get('variable_condition_groups', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CIResult(Model):
    """Represents response result type.

    :param exception_culprit: Possible values include: 'system', 'user',
     'external'
    :type exception_culprit: str or ~dynamics.customerinsights.api.models.enum
    :param error_code:
    :type error_code: str
    :param result_severity: Possible values include: 'error', 'warning',
     'recommendation'
    :type result_severity: str or ~dynamics.customerinsights.api.models.enum
    :param message: Message providing more information about the event.
    :type message: str
    :param name: Message providing more information about the event.
    :type name: str
    :param params:
    :type params: dict[str, object]
    :param ci_results: List of CiResult contining CI result error code and
     information (if any).
    :type ci_results: list[~dynamics.customerinsights.api.models.CIResult]
    """

    _attribute_map = {
        'exception_culprit': {'key': 'exceptionCulprit', 'type': 'str'},
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'result_severity': {'key': 'resultSeverity', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'params': {'key': 'params', 'type': '{object}'},
        'ci_results': {'key': 'ciResults', 'type': '[CIResult]'},
    }

    def __init__(self, **kwargs):
        super(CIResult, self).__init__(**kwargs)
        self.exception_culprit = kwargs.get('exception_culprit', None)
        self.error_code = kwargs.get('error_code', None)
        self.result_severity = kwargs.get('result_severity', None)
        self.message = kwargs.get('message', None)
        self.name = kwargs.get('name', None)
        self.params = kwargs.get('params', None)
        self.ci_results = kwargs.get('ci_results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CdsMdlInfo(Model):
    """The information on CDS MDL datalake folders.

    :param private_work_space:
    :type private_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    :param public_work_space:
    :type public_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    """

    _attribute_map = {
        'private_work_space': {'key': 'privateWorkSpace', 'type': 'DatalakeFolderDetail'},
        'public_work_space': {'key': 'publicWorkSpace', 'type': 'DatalakeFolderDetail'},
    }

    def __init__(self, *, private_work_space=None, public_work_space=None, **kwargs) -> None:
        super(CdsMdlInfo, self).__init__(**kwargs)
        self.private_work_space = private_work_space
        self.public_work_space = public_work_space



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Evaluation(Model):
    """Represents the measure evaluation details for a particular measure. It
    includes various properties pertaining to an
    evaluation including the measure name, orchestrationId, start time, state,
    errors (if-any) etc. This latest evaluation
    is stored in the measure metadata, while historical copies are written to
    table storage.

    :param last_successful_run_id:
    :type last_successful_run_id: str
    :param state: Possible values include: 'none', 'running', 'failed',
     'completed'
    :type state: str or ~dynamics.customerinsights.api.models.enum
    :param end_time: Evaluation completion time.
    :type end_time: datetime
    :param error: Error Information (if any) that occured during the measure
     evaluation.
    :type error: str
    """

    _attribute_map = {
        'last_successful_run_id': {'key': 'lastSuccessfulRunId', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'end_time': {'key': 'endTime', 'type': 'iso-8601'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(Evaluation, self).__init__(**kwargs)
        self.last_successful_run_id = kwargs.get('last_successful_run_id', None)
        self.state = kwargs.get('state', None)
        self.end_time = kwargs.get('end_time', None)
        self.error = kwargs.get('error', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureVariableConditionGroup(Model):
    """Represents a set of variable conditions to apply to a MeasureVariable.

    :param name: Attribute to use in condition.
    :type name: str
    :param conditions: Gets the MeasureVariableConditions.
    :type conditions:
     list[~dynamics.customerinsights.api.models.MeasureVariableCondition]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'conditions': {'key': 'conditions', 'type': '[MeasureVariableCondition]'},
    }

    def __init__(self, **kwargs):
        super(MeasureVariableConditionGroup, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.conditions = kwargs.get('conditions', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InsightActivityDetails(Model):
    """Collection of the Activity type and entity name corresponding to that
    activity type.

    :param activity_type: Gets the name of the activity Type.
    :type activity_type: str
    :param entity_name: Gets the name of the entity that corresponds to the
     activity type.
    :type entity_name: str
    :param activity_source_entities_info: Collection of the entity name and
     other info of the source activity entity ingested by user.
    :type activity_source_entities_info:
     list[~dynamics.customerinsights.api.models.ActivitySourceEntityInfo]
    """

    _attribute_map = {
        'activity_type': {'key': 'activityType', 'type': 'str'},
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'activity_source_entities_info': {'key': 'activitySourceEntitiesInfo', 'type': '[ActivitySourceEntityInfo]'},
    }

    def __init__(self, *, activity_type: str=None, entity_name: str=None, activity_source_entities_info=None, **kwargs) -> None:
        super(InsightActivityDetails, self).__init__(**kwargs)
        self.activity_type = activity_type
        self.entity_name = entity_name
        self.activity_source_entities_info = activity_source_entities_info
